summaryrefslogtreecommitdiffstats
path: root/kolourpaint/tools/kptoolpreviewdialog.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commite7366c97c998679efa80cf61c88e64a11a3d3c33 (patch)
treea161d2940165f6cc47c05f0271ad8e5f64ffe6e8 /kolourpaint/tools/kptoolpreviewdialog.h
parentda4be7880ff1de6415ab6256afd2514e64f5fa2e (diff)
downloadtdegraphics-e7366c97c998679efa80cf61c88e64a11a3d3c33.tar.gz
tdegraphics-e7366c97c998679efa80cf61c88e64a11a3d3c33.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegraphics@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kolourpaint/tools/kptoolpreviewdialog.h')
-rw-r--r--kolourpaint/tools/kptoolpreviewdialog.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kolourpaint/tools/kptoolpreviewdialog.h b/kolourpaint/tools/kptoolpreviewdialog.h
index 98cf28dc..5199a147 100644
--- a/kolourpaint/tools/kptoolpreviewdialog.h
+++ b/kolourpaint/tools/kptoolpreviewdialog.h
@@ -63,7 +63,7 @@ public:
// (in the Dimensions Group Box) e.g. "After Skew:"
const TQString &afterActionText,
bool actOnSelection,
- kpMainWindow *tqparent,
+ kpMainWindow *parent,
const char *name = 0);
virtual ~kpToolPreviewDialog ();
@@ -77,7 +77,7 @@ public:
protected:
kpDocument *document () const;
// All widgets must have mainWidget() as their tqparent
void addCustomWidgetToFront (TQWidget *w); // see <reserveTopRow> in ctor
void addCustomWidget (TQWidget *w);
void addCustomWidgetToBack (TQWidget *w)
@@ -77,7 +77,7 @@ public:
protected:
kpDocument *document () const;
- // All widgets must have mainWidget() as their tqparent
+ // All widgets must have mainWidget() as their parent
void addCustomWidgetToFront (TQWidget *w); // see <reserveTopRow> in ctor
void addCustomWidget (TQWidget *w);